pub fn connect_spawned_helper() -> Result<AuthenticatedChannel, LinuxError>Expand description
Connects the spawned helper using inherited freshness and expected-parent data.
pub fn connect_spawned_helper() -> Result<AuthenticatedChannel, LinuxError>Connects the spawned helper using inherited freshness and expected-parent data.