pub struct ChildSession { /* private fields */ }Expand description
Owned exact child process, authenticated control channel, and cleanup ledger.
Implementations
Sourceimpl ChildSession
impl ChildSession
Sourcepub fn spawn(program: &OsStr, arguments: &[&OsStr]) -> Result<Self, LinuxError>
pub fn spawn(program: &OsStr, arguments: &[&OsStr]) -> Result<Self, LinuxError>
Spawns an exact helper executable and authenticates its post-exec connection.
Sourcepub const fn channel(&self) -> &AuthenticatedChannel
pub const fn channel(&self) -> &AuthenticatedChannel
Authenticated capability-transfer channel.
Sourcepub const fn channel_mut(&mut self) -> &mut AuthenticatedChannel
pub const fn channel_mut(&mut self) -> &mut AuthenticatedChannel
Exclusive transaction access to the authenticated capability channel.
Sourcepub fn terminate(self) -> Result<(), LinuxError>
pub fn terminate(self) -> Result<(), LinuxError>
Requests termination and reaps the owned child.