pub struct PreparedWriter { /* private fields */ }Expand description
Sealed sole-writer mapping awaiting export/commit.
Implementations
Sourceimpl PreparedWriter
impl PreparedWriter
Sourcepub fn export_reader(&self) -> Result<ExportedReaderCapability, LinuxError>
pub fn export_reader(&self) -> Result<ExportedReaderCapability, LinuxError>
Duplicates a sealed descriptor that can create only future read-only mappings.
Sourcepub fn bind(self) -> Result<WriterRegion<LinuxWriterMapping>, LinuxError>
pub fn bind(self) -> Result<WriterRegion<LinuxWriterMapping>, LinuxError>
Commits the unique local writer into the audited core bridge.