pub struct ChildChannel { /* private fields */ }Expand description
Child side obtained from its injected special bootstrap port.
Implementations
Sourceimpl ChildChannel
impl ChildChannel
Sourcepub fn connect_from_environment() -> Result<Self, BootstrapError>
pub fn connect_from_environment() -> Result<Self, BootstrapError>
Connects using the injected special port and authenticated environment.
Sourcepub fn signal_ready(&self) -> Result<(), BootstrapError>
pub fn signal_ready(&self) -> Result<(), BootstrapError>
Signals that all imported mappings passed quiescent validation.
Sourceimpl ChildChannel
impl ChildChannel
Sourcepub fn receive_reader(
&self,
len: usize,
expected: ValidationExpectations,
topology: RegionSetLayout,
) -> Result<ReaderRegion<ImportedReaderMapping>, MacBindingError>
pub fn receive_reader( &self, len: usize, expected: ValidationExpectations, topology: RegionSetLayout, ) -> Result<ReaderRegion<ImportedReaderMapping>, MacBindingError>
Receives and binds a read-only memory entry while the parent is quiescent.
Sourcepub fn receive_writer(
&self,
len: usize,
expected: ValidationExpectations,
topology: RegionSetLayout,
) -> Result<WriterRegion<ImportedWriterMapping>, MacBindingError>
pub fn receive_writer( &self, len: usize, expected: ValidationExpectations, topology: RegionSetLayout, ) -> Result<WriterRegion<ImportedWriterMapping>, MacBindingError>
Receives and binds the sole writable memory entry while quiescent.